Garfield.nn.GCNEncoder
======================

.. currentmodule:: Garfield.nn

.. autoclass:: GCNEncoder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GCNEncoder.__init__
      ~GCNEncoder.add_module
      ~GCNEncoder.apply
      ~GCNEncoder.bfloat16
      ~GCNEncoder.buffers
      ~GCNEncoder.children
      ~GCNEncoder.compile
      ~GCNEncoder.cpu
      ~GCNEncoder.cuda
      ~GCNEncoder.double
      ~GCNEncoder.eval
      ~GCNEncoder.extra_repr
      ~GCNEncoder.float
      ~GCNEncoder.forward
      ~GCNEncoder.get_buffer
      ~GCNEncoder.get_extra_state
      ~GCNEncoder.get_parameter
      ~GCNEncoder.get_submodule
      ~GCNEncoder.half
      ~GCNEncoder.ipu
      ~GCNEncoder.load_state_dict
      ~GCNEncoder.modules
      ~GCNEncoder.named_buffers
      ~GCNEncoder.named_children
      ~GCNEncoder.named_modules
      ~GCNEncoder.named_parameters
      ~GCNEncoder.parameters
      ~GCNEncoder.register_backward_hook
      ~GCNEncoder.register_buffer
      ~GCNEncoder.register_forward_hook
      ~GCNEncoder.register_forward_pre_hook
      ~GCNEncoder.register_full_backward_hook
      ~GCNEncoder.register_full_backward_pre_hook
      ~GCNEncoder.register_load_state_dict_post_hook
      ~GCNEncoder.register_module
      ~GCNEncoder.register_parameter
      ~GCNEncoder.register_state_dict_pre_hook
      ~GCNEncoder.requires_grad_
      ~GCNEncoder.set_extra_state
      ~GCNEncoder.share_memory
      ~GCNEncoder.state_dict
      ~GCNEncoder.to
      ~GCNEncoder.to_empty
      ~GCNEncoder.train
      ~GCNEncoder.type
      ~GCNEncoder.xpu
      ~GCNEncoder.zero_grad
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GCNEncoder.T_destination
      ~GCNEncoder.call_super_init
      ~GCNEncoder.dump_patches
      ~GCNEncoder.training
   
   